==> django-chatter-0.0.3.tar.gz: django-chatter-0.0.3/chat/models.py <==
import shortuuid

from django.conf import settings
from django.db import models


class UserProfile(models.Model):
    user = models.OneToOneField(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='profile')
    last_visit = models.DateTimeField()

# This model is used to give date and time when a message was created/modified.
class DateTimeModel(models.Model):
    date_created = models.DateTimeField(auto_now_add=True)
    date_modified = models.DateTimeField(auto_now=True)

    class Meta:
        abstract = True

class Room(DateTimeModel):
    id = models.URLField(primary_key=True, default=shortuuid.ShortUUID().random(length=22),
            editable=False
        )
    members = models.ManyToManyField(settings.AUTH_USER_MODEL)

    def __str__(self):
        room = Room.objects.get(id=self.id)
        memberset = room.members.all()
        members_list = []
        for member in memberset:
            members_list.append(member.username)

        return str(members_list)

class Message(DateTimeModel):
    sender = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='sender')
    room = models.ForeignKey(Room, on_delete=models.CASCADE)
    text = models.TextField()
    recipients = models.ManyToManyField(settings.AUTH_USER_MODEL, related_name='recipients')

    def __str__(self):
        return '"{}" \
        sent by "{}" \
        in Room "{}"'.format(
                        self.text,
                        self.sender,
                        self.room
                    )

==> django-chatter-0.0.4.tar.gz: django-chatter-0.0.4/chat/models.py <==
import shortuuid

from django.conf import settings
from django.db import models


class UserProfile(models.Model):
    user = models.OneToOneField(
        settings.AUTH_USER_MODEL,
        on_delete=models.CASCADE,
        related_name='profile')
    last_visit = models.DateTimeField()

# This model is used to give date and time when a message was created/modified.
class DateTimeModel(models.Model):
    date_created = models.DateTimeField(auto_now_add=True)
    date_modified = models.DateTimeField(auto_now=True)

    class Meta:
        abstract = True

class Room(DateTimeModel):
    id = models.URLField(
        primary_key=True,
        default=shortuuid.ShortUUID.random,
        editable=False
        )
    members = models.ManyToManyField(settings.AUTH_USER_MODEL)

    def __str__(self):
        room = Room.objects.get(id=self.id)
        memberset = room.members.all()
        members_list = []
        for member in memberset:
            members_list.append(member.username)

        return str(members_list)

class Message(DateTimeModel):
    sender = models.ForeignKey(
        settings.AUTH_USER_MODEL,
        on_delete=models.CASCADE,
        related_name='sender')
    room = models.ForeignKey(Room, on_delete=models.CASCADE)
    text = models.TextField()
    recipients = models.ManyToManyField(
        settings.AUTH_USER_MODEL,
        related_name='recipients')

    def __str__(self):
        return '"{}" \
        sent by "{}" \
        in Room "{}"'.format(
                        self.text,
                        self.sender,
                        self.room
                    )
